@@ -1,11 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2006 by Matthew Williams    <matt@milliams.com>         *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006 Matthew Williams <matt@milliams.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 //header
 #include "ksquaresdemowindow.h"
@@ -36,7 +33,7 @@ KSquaresDemoWindow::KSquaresDemoWindow() : KXmlGuiWindow(), m_view(new GameBoard
     m_view->setDisabled(true);
     setCentralWidget(m_view);
 
-    KStandardGameAction::quit(qApp, SLOT(quit()), actionCollection());
+    KStandardGameAction::quit(qApp, &QApplication::quit, actionCollection());
     setupGUI();
 
     //QT5 statusBar()->insertPermanentItem(i18n("Current Player"), 0);
